// Class: Example2
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.BoundedGrid;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.GridObject;
import edu.kzoo.grid.Location;

import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.ScaledImageDisplay;

import edu.kzoo.grid.gui.GridAppFrame;
import edu.kzoo.grid.gui.nuggets.MinimalFileMenu;

/**
 *  Grid Package Examples:<br>
 * 
 *    The Example2 class constructs a simple graphical user interface
 *    that displays an animation of a queen moving diagonally on a
 *    single-colored "chessboard." 
 *
 *  @author Alyce Brady
 *  @version 30 June 2004
 **/
public class Example2
{
    // Specify attributes of the grid.
    private static final int NUM_ROWS_COLS = 8;

    // Specify attributes of the grid display.
    private static final int MAX_WIDTH = 400;
    private static final int MAX_HEIGHT = 400;
    private static final int MIN_CELL_SIZE = 20;
    private static final Color BACKGROUND_COLOR = Color.WHITE;

    /**
     *  Start the Example2 program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        // Construct a window in which to display a grid.  Include a
        // file menu that consists solely of a Quit option.  Specify how
        // to display a queen represented as a simple GridObject instance.
        GridAppFrame gui = new GridAppFrame();
        gui.includeMenu(new MinimalFileMenu());
        gui.includeSpeedSlider();
        gui.constructWindowContents("Example 2: Animation with File Menu",
                                    BACKGROUND_COLOR, 
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);
        DisplayMap.associate("edu.kzoo.grid.GridObject",
                             new ScaledImageDisplay("GoldCrown.gif"));

        // Construct a grid for the chessboard.
        Grid grid = new BoundedGrid(NUM_ROWS_COLS, NUM_ROWS_COLS);
        gui.setGrid(grid);

        // Move the queen diagonally from upper-left to lower-right ten times.
        for ( int count = 0; count < 10; count++ )
        {
            grid.add(new GridObject(), new Location(0, 0));
            gui.showGrid();
            for ( int newIndex = 1; newIndex < NUM_ROWS_COLS; newIndex++ )
            {
                int oldIndex = newIndex - 1;
                Location oldLoc = new Location(oldIndex, oldIndex);
                Location newLoc = new Location(newIndex, newIndex);
                grid.remove(grid.objectAt(oldLoc));
                grid.add(new GridObject(), newLoc);
                gui.showGrid();
            }
            // Remove queen in preparation for next time through outer loop
            grid.remove(grid.objectAt(new Location(NUM_ROWS_COLS - 1,
                                                   NUM_ROWS_COLS - 1)));
        }
    }

}
