// Class: Example4GUI
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.gui.EnabledDisabledStates;
import edu.kzoo.grid.gui.GridAppFrame;
import edu.kzoo.grid.gui.ThreadedControlButton;
import edu.kzoo.grid.gui.nuggets.MinimalFileMenu;
import edu.kzoo.grid.gui.nuggets.NewBoundedGridButton;

/**
 *  Grid Package Examples:<br>
 *
 *    The Example4GUI class represents a simple graphical user interface
 *    that redefines the restart method to start an animation of a queen
 *    moving diagonally on a single-colored "chessboard." 
 *
 *  @author Alyce Brady
 *  @version 15 August 2004
 **/
public class Example4GUI extends GridAppFrame
{
    // Specify attributes of the grid display.
    private static final int MAX_WIDTH = 400;
    private static final int MAX_HEIGHT = 400;
    private static final int MIN_CELL_SIZE = 20;
    private static final Color BACKGROUND_COLOR = Color.WHITE;

    // Specify attributes of the Start button.
    private static final boolean DISPLAY_AFTER_START = true;

    // Instance variable(s) for each Example4GUI instance.
    private Example4AppControl controller;

    /** Constructs a new Example4GUI object. **/
    public Example4GUI()
    {
        // Create object that knows how to run the animation.
        controller = new Example4AppControl(this);

        // Create the components for this user interface.
        includeMenu(new MinimalFileMenu());
        includeMenu(new ExampleHelpMenu(
            "Example 4: Model-View-Controller Separation " +
            "within the Grid Package",
            "15 August 2004"));

        includeControlComponent(new NewBoundedGridButton(this, "New Grid"),
                                EnabledDisabledStates.NEEDS_APP_WAITING);

        includeControlComponent(
            new ThreadedControlButton(this, "Start", DISPLAY_AFTER_START)
                { public void act() { controller.runAnimation(); }},
            EnabledDisabledStates.NEEDS_GRID_AND_APP_WAITING);

        includeSpeedSlider();

        // Construct the visible window with the specified components.
        constructWindowContents("Example 4: Model-View-Controller Separation",
                                BACKGROUND_COLOR, 
                                MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);
    }

}
