// Class: Example5App
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import edu.kzoo.grid.display.ColorBlockDisplay;
import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.gui.EnabledDisabledStates;
import edu.kzoo.grid.gui.GeneratedButtonList;
import edu.kzoo.grid.gui.GridAppFrame;
import edu.kzoo.grid.gui.nuggets.BGColorChoiceMenu;
import edu.kzoo.grid.gui.nuggets.ClearGridButton;
import edu.kzoo.grid.gui.nuggets.ColorChoiceMenu;
import edu.kzoo.grid.gui.nuggets.MinimalFileMenu;
import edu.kzoo.grid.gui.nuggets.NewBoundedGridButton;

/**
 *  Grid Package Examples:<br>
 * 
 *    The Example5App class constructs a graphical user interface that
 *    includes a New Grid button, a background color chooser, a
 *    Reset button, and a group of buttons generated automatically
 *    by looking at the methods of another class.
 *
 *  @author Alyce Brady
 *  @version 15 August 2004
 **/
public class Example5App
{
    // Specify attributes of the grid display.
    private static final int MAX_WIDTH = 400;
    private static final int MAX_HEIGHT = 400;
    private static final int MIN_CELL_SIZE = 20;
    private static final boolean DISPLAY_GRID_AFTER_BUTTON_PRESSES = true;

    /**
     *  Start the Example5App program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        // This application will use control buttons generated from the
        // methods in the Example5AppControl class.  Construct the
        // Example5AppControl object that will be sent messages in
        // response to user clicks on the generated control buttons.
        // (This is the target object.)  Then generate a list of the
        // arguments to be sent to the target object's control methods
        // (in this case, a single, arbitrary Color object.)
        Example5AppControl targetObject = new Example5AppControl();
        Object[] generatedButtonArguments = new Object[1];
          // contents of generatedButtonArguments is set by color choice menu

        // Construct a window in which to display a grid with color blocks.  
        // Include File and Help menus.
        GridAppFrame gui = new GridAppFrame();
        gui.includeMenu(new MinimalFileMenu());
        gui.includeMenu(new ExampleHelpMenu(
            "Example 5: Automatically Generated Buttons " +
            "within the Grid Package",
            "15 August 2004"));
        DisplayMap.associate("edu.kzoo.grid.ColorBlock",
                             new ColorBlockDisplay());

        // Include a New Grid button.
        gui.includeControlComponent(new NewBoundedGridButton(gui, "New Grid"),
                                    EnabledDisabledStates.NEEDS_APP_WAITING);

        // Include a background color chooser component.
        ColorChoiceMenu bgColorChooser = new BGColorChoiceMenu(gui);
        gui.includeControlComponent(bgColorChooser,
                                    EnabledDisabledStates.NEEDS_APP_WAITING);

        // Include a color chooser component for color blocks.  It should
        // update the first argument in generatedButtonArguments whenever a
        // new color is chosen.
        ColorChoiceMenu colorBlockColorChooser =
                    new Example5ColorChoiceMenu("Fill Color", "Red",
                                                generatedButtonArguments, 0);
        generatedButtonArguments[0] = colorBlockColorChooser.currentColor();
        gui.includeControlComponent(colorBlockColorChooser,
                                    EnabledDisabledStates.NEEDS_APP_WAITING);

        // Generate control buttons derived from the methods of the target
        // object and include them in the user interface.  Since
        // the grid is set by a New Grid button, the object with the control
        // button methods should be a grid change listener. 
        GeneratedButtonList generatedButtonList = 
            new GeneratedButtonList(gui,
                                    targetObject, generatedButtonArguments,
                                    DISPLAY_GRID_AFTER_BUTTON_PRESSES);
        gui.includeControlComponents(generatedButtonList,
                            EnabledDisabledStates.NEEDS_GRID_AND_APP_WAITING);
        gui.addGridChangeListener(targetObject);
        // If you know what methods will be created, you can customize the
        // button labels.
        generatedButtonList.resetButtonLabel("fill", "Fill all cells");

        // Include a Reset button that clears the grid.
        gui.includeControlComponent(
            new ClearGridButton(gui, "Empty Grid",
                                DISPLAY_GRID_AFTER_BUTTON_PRESSES),
            EnabledDisabledStates.NEEDS_GRID_AND_APP_WAITING);

        // Construct the visible window with the specified components.
        gui.constructWindowContents("Example 5: Derived Buttons",
                                    bgColorChooser.currentColor(),
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);
    }

}
