// Class: Example5AppControl
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.ColorBlock;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.Location;
import edu.kzoo.grid.gui.GridChangeListener;

/**
 *  Grid Package Examples:<br>
 *
 *    The Example5AppControl class is an example of a class that
 *    provides methods that should have control buttons created for
 *    them.  The control methods in this class draw in the grid by
 *    placing color blocks in the grid's cells.  Each control method
 *    takes a Color object as a parameter (the color with which to
 *    draw), and has a void return type.  This restriction allows the
 *    graphical user interface to recognize the control methods,
 *    for which it automatically generates buttons.
 *
 *  @author Alyce Brady
 *  @version 29 July 2004
 **/

public class Example5AppControl implements GridChangeListener
{
  // Instance Variables: Encapsulated data for EACH Example5AppControl object
    private Grid theGrid = null;

  // constructor

    /** Constructs an object that can draw in a grid.
     **/
    public Example5AppControl()
    {
    }

    /** Constructs an object that draws in the specified grid.
     **/
    public Example5AppControl(Grid grid)
    {
        theGrid = grid;
    }

  // accessor method to change state

    /** Sets the grid in which to draw.
     **/
    public void reactToNewGrid(Grid grid)
    {
        theGrid = grid;
    }

  // drawing methods

    /** Fills in all the cells of the grid.
     *      @param  color the color to use when filling in cells
     **/
    public void fill(Color color)
    {
        if ( theGrid == null )
            return;

        for ( int row = 0; row < theGrid.numRows(); row++ )
        {
            for ( int column = 0; column < theGrid.numCols(); column++ )
            {
                placeColorBlock(color, row, column);
            }
        }
    }

    /** Fills in a diagonal from the upper-left corner.
     *      @param  color the color to use when filling in cells
     **/
    public void drawDiagonal(Color color)
    {
        if ( theGrid == null )
            return;

        for ( int row = 0; row < theGrid.numRows(); row++ )
        {
            if ( row < theGrid.numCols() )
            {
                placeColorBlock(color, row, row);
            }
        }
    }

    /** Fills in the cells along the perimeter of the grid.
     *      @param  color the color to use when filling in cells
     **/
    public void onDrawPerimeterButtonClick(Color color)
    {
        if ( theGrid == null )
            return;

        // Fill cells along top and bottom rows.
        for ( int col = 0; col < theGrid.numCols(); col++ )
        {
            placeColorBlock(color, 0, col);
            placeColorBlock(color, theGrid.numRows() - 1, col);
        }

        // Fill cells along left and right sides.
        for ( int row = 0; row < theGrid.numRows(); row++ )
        {
            placeColorBlock(color, row, 0);
            placeColorBlock(color, row, theGrid.numCols() - 1);
        }
    }

  // helper methods that are called by other methods

    /** Ensures that the specified location is empty by removing the object
     *  there, if there is one.
     *      @param row      row number of location that should be empty
     *      @param column   column number of location that should be empty
     **/
    private void ensureEmpty(int row, int column)
    {
        // If the specified location in the grid is not empty,
        // remove whatever object is there.
        Location loc = new Location(row, column);
        if ( ! theGrid.isEmpty(loc) )
            theGrid.remove(theGrid.objectAt(loc));
    }

    /** Puts a color block of the specified color in the specified location
     *  and redisplays the grid.
     *      @param color    menu indicating choice of color
     *      @param row      row in which to place the new color block
     *      @param column   column in which to place the new color block
     **/
    private void placeColorBlock(Color color, int row, int column)
    {
        // First remove any color block that happens to be at this location.
        ensureEmpty(row, column);

        // Construct the color block, which adds itself to the grid.
        // Then display the grid.
        Location loc = new Location(row, column);
        new ColorBlock(color, theGrid, loc);
    }

}
