// Class: Figure1
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.ColorBlock;
import edu.kzoo.grid.BoundedGrid;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.Location;
import edu.kzoo.grid.TextCell;

import edu.kzoo.grid.display.ColorBlockDisplay;
import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.TextCellDisplay;

import edu.kzoo.grid.gui.GridAppFrame;

/**
 *  Grid Package Examples:<br>
 * 
 *    The <code>Figure1</code> class produces the first figure in the
 *    Grid Package Overview document.  It constructs a simple graphical
 *    user interface that displays a text cell and a color block in a grid.
 *
 *  @author Alyce Brady
 *  @version 30 June 2004
 **/
public class Figure1
{
    /**
     *  Start the Figure1 program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        String TITLE = "Figure 1";
        Color BACKGROUND_COLOR = Color.WHITE;
        int MAX_WIDTH = 100;       // in pixels
        int MAX_HEIGHT = 100;      // in pixels
        int MIN_CELL_SIZE = 20;   // in pixels

        // Construct a window to display a grid.
        GridAppFrame gui = new GridAppFrame();
        gui.constructWindowContents(TITLE, BACKGROUND_COLOR, 
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);

        // Specify how to display color blocks.
        DisplayMap.associate("edu.kzoo.grid.ColorBlock",
                             new ColorBlockDisplay());
        DisplayMap.associate("edu.kzoo.grid.TextCell", new TextCellDisplay());

        // Construct a grid in which to draw.
        // Add a text cell and a color block.
        Grid grid = new BoundedGrid(3, 3);
        gui.setGrid(grid);
        grid.add(new TextCell("A"), new Location(0, 0));
        grid.add(new ColorBlock(Color.RED), new Location(2, 2));

        // Display the grid.
        gui.showGrid();
    }

}
