// Class: Figure2a
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.BoundedGrid;
import edu.kzoo.grid.ColorBlock;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.Location;
import edu.kzoo.grid.TextCell;

import edu.kzoo.grid.display.ColorBlockDisplay;
import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.TextCellDisplay;

import edu.kzoo.grid.gui.GridAppFrame;

/**
 *  Grid Package Examples:<br>
 * 
 *    The <code>Figure2a</code> class produces the first in a series of
 *    figures showing different types of grid-based applications in the
 *    Grid Package Overview document.  It shows a simplified version of the
 *    histogram in Example1.
 *
 *  @author Alyce Brady
 *  @version 30 June 2004
 **/
public class Figure2a
{
    /**
     *  Start the Figure2a program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        String TITLE = "Figure 2a";
        Color BACKGROUND_COLOR = Color.WHITE;
        int MAX_WIDTH = 400;       // in pixels
        int MAX_HEIGHT = 400;      // in pixels
        int MIN_CELL_SIZE = 20;   // in pixels

        // Construct a window to display a grid.
        GridAppFrame gui = new GridAppFrame();
        gui.constructWindowContents(TITLE, BACKGROUND_COLOR, 
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);

        // Specify how to display color blocks.
        DisplayMap.associate("edu.kzoo.grid.ColorBlock",
                             new ColorBlockDisplay());
        DisplayMap.associate("edu.kzoo.grid.TextCell", new TextCellDisplay());

        // Construct a grid in which to draw.
        Grid grid = new BoundedGrid(9, 9);
        gui.setGrid(grid);

        // Add some color blocks and text cells to the grid in
        // the form of a simple histogram.
        grid.add(new TextCell("B"), new Location(1, 0));
        grid.add(new TextCell("A"), new Location(1, 1));
        grid.add(new TextCell("R"), new Location(1, 2));
        grid.add(new TextCell("C"), new Location(1, 4));
        grid.add(new TextCell("H"), new Location(1, 5));
        grid.add(new TextCell("A"), new Location(1, 6));
        grid.add(new TextCell("R"), new Location(1, 7));
        grid.add(new TextCell("T"), new Location(1, 8));
        grid.add(new TextCell("1"), new Location(3, 0));
        for ( int i = 1; i < 8; i++ )
            grid.add(new ColorBlock(Color.RED), new Location(3, i));
        grid.add(new TextCell("2"), new Location(6, 0));
        for ( int i = 1; i < 5; i++ )
            grid.add(new ColorBlock(Color.BLUE), new Location(6, i));

        // Display the grid.
        gui.showGrid();
    }

}
