// Class: OverviewExample3
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import edu.kzoo.grid.gui.ControlButton;
import edu.kzoo.grid.gui.EnabledDisabledStates;
import edu.kzoo.grid.gui.GridAppFrame;
import edu.kzoo.grid.gui.nuggets.BGColorChoiceMenu;
import edu.kzoo.grid.gui.nuggets.ClearGridButton;
import edu.kzoo.grid.gui.nuggets.ColorChoiceMenu;
import edu.kzoo.grid.gui.nuggets.NewBoundedGridButton;

/**
 *  Grid Package Examples:<br>
 * 
 *    The OverviewExample3 class implements the third example in the
 *    Grid Package Overview document.  It constructs a simple graphical
 *    user interface containing several pre-defined components from the
 *    edu.kzoo.grid.gui.nuggets package.
 *
 *  @author Alyce Brady
 *  @version 1 September 2004
 **/
public class OverviewExample3
{
    /**
     *  Start the OverviewExample3 program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        String TITLE = "Overview Example 3";
        int MAX_WIDTH = 600;      // in pixels
        int MAX_HEIGHT = 600;     // in pixels
        int MIN_CELL_SIZE = 10;   // in pixels

        int ENABLE_WHEN_WAITING = EnabledDisabledStates.NEEDS_APP_WAITING;
        int NEEDS_GRID = EnabledDisabledStates.NEEDS_GRID_AND_APP_WAITING;
        boolean DISPLAY_GRID_AFTER_CLEARING = true;

        // Construct a window with a new grid button, a background color
        // chooser, and a clear grid button.

        GridAppFrame gui = new GridAppFrame();
        ControlButton
                newGridButton = new NewBoundedGridButton(gui, "New Grid"),
                clearButton = new ClearGridButton(gui, "Empty Grid",
                                                  DISPLAY_GRID_AFTER_CLEARING),
                resetButton = new ResetButton(gui);
        ColorChoiceMenu bgColorChooser = new BGColorChoiceMenu(gui);
        gui.includeControlComponent(newGridButton, ENABLE_WHEN_WAITING);
        gui.includeControlComponent(bgColorChooser, ENABLE_WHEN_WAITING);
        gui.includeControlComponent(clearButton, NEEDS_GRID);
        gui.includeControlComponent(resetButton,
                                    EnabledDisabledStates.ALWAYS_ENABLED);
        gui.constructWindowContents(TITLE, bgColorChooser.currentColor(),
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);
    }

    public static class ResetButton extends ControlButton
    {
        private static final boolean DISPLAY_AFTER_RESET = true;

        public ResetButton(GridAppFrame gui)
        {
            super(gui, "Reset", DISPLAY_AFTER_RESET);
        }

        public void act()
        {
            getGUI().setGrid(null);
            getGUI().resetDelay();
        }
    }

}
