// Class: RotatedTintedExample
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.BoundedGrid;
import edu.kzoo.grid.Direction;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.Location;

import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.ScaledImageDisplay;
import edu.kzoo.grid.display.RotatedDecorator;
import edu.kzoo.grid.display.ScaledImageTintDecorator;

import edu.kzoo.grid.gui.GridAppFrame;

/**
 *  Grid Package Examples:<br>
 * 
 *    The RotatedTintedExample class constructs a simple graphical user interface
 *    that displays a bounded grid with fish facing different
 *    directions.  The fish are represented with a GIF image.  This
 *    example illustrates the use of a scaled, rotated, and tinted image. 
 *
 *  @author Alyce Brady
 *  @version 30 June 2004
 **/
public class RotatedTintedExample
{
    // Specify attributes of the grid.
    private static final int NUM_ROWS = 5;
    private static final int NUM_COLS = 9;

    // Specify attributes of the grid display.
    private static final int MAX_WIDTH = 450;
    private static final int MAX_HEIGHT = 250;
    private static final int MIN_CELL_SIZE = 20;
    private static final Color BACKGROUND_COLOR = Color.BLUE;

    /**
     *  Start the RotatedTintedExample program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        // Construct a grid in which to draw.
        Grid grid = new BoundedGrid(NUM_ROWS, NUM_COLS);

        // Construct a window to display a grid.
        GridAppFrame display = new GridAppFrame();
        display.constructWindowContents("Rotated Tinted Image Example",
                                        BACKGROUND_COLOR, 
                                        MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);
        display.setGrid(grid);

        // Add objects that will be displayed by the RotatedColorObjectDisplay
        // (a default located automatically since we aren't specifying how
        // to display RotatedColorObject objects explicitly to the DisplayMap).
        // The RotatedColorObjectDisplay class uses a rotated tinted image.
        new RotatedColorObject(grid, new Location(1, 1), Direction.EAST, Color.RED);
        new RotatedColorObject(grid, new Location(1, 3), Direction.SOUTH, Color.GREEN);
        new RotatedColorObject(grid, new Location(1, 5), Direction.WEST, Color.YELLOW);
        new RotatedColorObject(grid, new Location(1, 7), Direction.NORTH, Color.CYAN);

        // It is not necessary to create a display class to rotate or tint
        // an image; it can be done directly in client code like this.
        ScaledImageDisplay imageDisplay = new ScaledImageDisplay("smallfish.gif");
        imageDisplay.addDecorator(new RotatedDecorator(Direction.EAST));
        imageDisplay.addDecorator(new ScaledImageTintDecorator());       
        DisplayMap.associate("RotatedColorObject2",  imageDisplay);

        // Add objects that will be displayed with the imageDisplay above.
        new RotatedColorObject2(grid, new Location(3, 1), Direction.EAST, Color.RED);
        new RotatedColorObject2(grid, new Location(3, 3), Direction.SOUTH, Color.GREEN);
        new RotatedColorObject2(grid, new Location(3, 5), Direction.WEST, Color.YELLOW);
        new RotatedColorObject2(grid, new Location(3, 7), Direction.NORTH, Color.CYAN);

        // Display the grid.
        display.showGrid();
    }

}
