// Class: SimplifiedColorExample
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import edu.kzoo.grid.BoundedGrid;
import edu.kzoo.grid.ColorBlock;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.Location;
import edu.kzoo.grid.display.ColorBlockDisplay;
import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.gui.EnabledDisabledStates;
import edu.kzoo.grid.gui.GridAppFrame;
import edu.kzoo.grid.gui.nuggets.ColorChoiceMenu;
import edu.kzoo.grid.gui.nuggets.MinimalFileMenu;
import edu.kzoo.util.NamedColor;

/**
 *  Grid Package Examples:<br>
 *
 *    The SimplifiedColorExample class constructs a simple graphical user
 *    interface that displays various colors defined in the NamedColor class. 
 *
 *  @author Alyce Brady
 *  @version Sep 4, 2004
 **/
public class SimplifiedColorExample extends GridAppFrame
{
    private static final boolean DISPLAY_GRID_AFTER_BUTTON_PRESSES = true;

    private ColorChoiceMenu menu;

    public static void main(String[] args)
    {
        SimplifiedColorExample example = new SimplifiedColorExample();
    }

    public SimplifiedColorExample()
    {
        includeMenu(new MinimalFileMenu());

        // Create a standard color choice menu, specifying the default color.
        // Add another color to it.
        menu = new ColorChoiceMenu("Pick a color: ");
        menu.addColorChoice(new NamedColor(192, 10, 72, "Burgundy"));
        includeControlComponent(menu,
                                EnabledDisabledStates.NEEDS_APP_WAITING);

        // Construct the window.  Specify how to display color blocks.
        // Have the display show object toString information in tool tips, not
        // just grid locations.
        constructWindowContents("Color Example with Clickable Cells",
                                NamedColor.WHITE, 400, 400, 10);
        DisplayMap.associate("edu.kzoo.grid.ColorBlock",
                             new ColorBlockDisplay());
        getDisplay().makeToolTipsReportObject();

        // Create the grid.
        Grid grid = new BoundedGrid(10, 10);
        setGrid(grid);
    }

    /** Handles a mouse press over the grid display.  Creates a color block
     *  in the specified location if there isn't one there already, or
     *  removes the current color block if there is one.  The color of
     *  new color blocks is determined by the current choice in the color
     *  choice menu.
     **/
    protected void onMousePressOverDisplay(Location loc)
    {
        if ( getGrid().isEmpty(loc) )
            getGrid().add(new ColorBlock(menu.currentColor()), loc);
        else
            getGrid().remove(loc);
        showGrid();
    }

}
