// Class MBSSimulationWrapper
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

package edu.kzoo.mbsInAGrid.gui;

import edu.kzoo.grid.Grid;
import edu.kzoo.grid.display.ScrollableGridDisplay;
import edu.kzoo.grid.gui.SteppedGridAppController;

import edu.kzoo.mbsInAGrid.Simulation;

/**
 *  Grid Container Package Examples:<br>
 *
 *    The <code>MBSSimulationWrapper</code> class provides a
 *    <code>GridAppController</code> wrapper around the MBS
 *    <code>Simulation</code> class.
 *
 *  @author Alyce Brady
 *  @version 18 March 2004
 **/
public class MBSSimulationWrapper extends SteppedGridAppController
{
    private ScrollableGridDisplay display;
    private Simulation simulation;


  // constructors and initialization methods

    /** Creates a wrapper around the <code>Simulation</code> class
     *  that can be used as the controller for the <code>MBSWindow</code>
     *  graphical user interface.
     **/
    public MBSSimulationWrapper()
    {
        this.display = null;
        this.simulation = null;
    }

    /** Sets the display to be used by <code>Simulation</code> instances. **/
    public void setDisplay(ScrollableGridDisplay display)
    {
        this.display = display;
    }

    /** Sets the application's grid.
     *  (Precondition: grid is not null.)
     *    @param grid the Grid to act on
     **/
    public void setGrid(Grid grid)
    {
        super.setGrid(grid);
        if ( display!= null && grid != null )
            simulation = new Simulation(grid, display);
    }

  // methods that control the running of the application

    /** Advances the application one step. 
     **/
    public void step()
    {
        if ( simulation != null )
            simulation.step();
    }

}


