// Class MBSWindow
//
// Author: Alyce Brady
//
// This class is based on the College Board's MBSGUIFrame class,
// as allowed by the GNU General Public License.  MBSGUIFrame
// is a black-box class within the AP(r) CS Marine Biology Simulation
// case study (see www.collegeboard.com/ap/students/compsci).
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

package edu.kzoo.mbsInAGrid.gui;

import javax.swing.JMenu;

import edu.kzoo.grid.gui.nuggets.BasicGridFileMenu;
import edu.kzoo.grid.gui.nuggets.BasicHelpMenu;
import edu.kzoo.grid.gui.SteppedGridAppFrame;


/**
 *  Grid Container Package Examples:<br>
 *
 *    The <code>MBSWindow</code> class provides a window in which
 *    to run and display a Marine Biology Simulation environment.
 *
 *  @author Alyce Brady (based on code by Julie Zelenski)
 *  @version 1 December 2002
 **/
public class MBSWindow extends SteppedGridAppFrame
{
    // Specify button attributes.
    private static final boolean DISPLAY_AFTER_EACH_STEP = true;

  // constructors and initialization methods

    /** Creates an MBSWindow.
     **/
    public MBSWindow()
    {
        // MBSWindow uses the MBS Simulation object as its controller,
        // but Simulation does not extend GridAppController so it must
        // be wrapped up in the MBSSimulationWrapper.
        super(new MBSSimulationWrapper(), DISPLAY_AFTER_EACH_STEP);
        MBSMenuActionHandler menuActionHandler =
                                        new MBSMenuActionHandler(this);
        includeMenu(new BasicGridFileMenu(this, menuActionHandler, 
            new MBSDataFileHandler()));
        includeMenu(new MBSSeedMenu(menuActionHandler));
        JMenu helpMenu = new BasicHelpMenu(
            "Marine Biology Simulation Variation " +
            "with Grid Package GUI",
            "Alyce Brady",
            "The Grid Package was inspired by the AP&reg; Computer Science" +
            "<br>Marine Biology Simulation Case Study, " +
            "whose graphical user interface code was<br>written " +
            "primarily by Julie Zelenski.", "15 August 2004");
        includeMenu(helpMenu);
        includeSpeedSlider();
        includeStepOnceButton();
        includeStepNTimesButton();
        includeRunButton();
        includeStopButton(true);              // stop and display
        constructWindowContents("Marine Biology Simulation", null, 0, 0, 0);
        ((MBSSimulationWrapper)getController()).setDisplay(getDisplay());
        getDisplay().makeToolTipsReportObject();
    }

}


