/*
 * File: GResizable.java
 * ---------------------
 * This interface specifies the characteristics of a graphical object that
 * supports setSize and setBounds.
 */

// ************************************************************************
// *  For the beta release, the source code for the libraries continues   *
// *  to be licensed under the following Creative Commons license:        *
// *                                                                      *
// *                 Attribution-NonCommercial-NoDerivs                   *
// *                                                                      *
// *  When the final release is posted, we plan to reduce these           *
// *  restrictions to allow any use, protecting only the ACM's right      *
// *  to prevent others from selling these libraries as their own.        *
// ************************************************************************

package acm.graphics;

/* Interface: GResizable */
/**
 * Specifies the characteristics of a graphical object that supports the
 * <code>setSize</code> and <code>setBounds</code> methods.
 */
public interface GResizable {

/* Method: setSize(width, height) */
/**
 * Changes the size of this object to the specified width and height.
 *
 * @usage gobj.setSize(width, height);
 * @param width The new width of the object
 * @param height The new height of the object
 */
	public void setSize(double width, double height);

/* Method: setSize(size) */
/**
 * Changes the size of this object as specified by the <code>GDimension</code>
 * object.
 *
 * @usage gobj.setSize(size);
 * @param size A <code>GDimension</code> object specifying the new size
 */
	public void setSize(GDimension size);

/* Method: setBounds(x, y, width, height) */
/**
 * Changes the bounds of this object to the specified values.
 *
 * @usage gobj.setBounds(x, y, width, height);
 * @param x The new x-coordinate for the object
 * @param y The new y-coordinate for the object
 * @param width The new width of the object
 * @param height The new height of the object
 */
	public void setBounds(double x, double y, double width, double height);

/* Method: setBounds(bounds) */
/**
 * Changes the bounds of this object to the values from the specified
 * <code>GRectangle</code>.
 *
 * @usage gobj.setBounds(bounds);
 * @param bounds A <code>GRectangle</code> specifying the new bounds
 */
	public void setBounds(GRectangle bounds);

}
