/*
 * File: HPanel.java
 * -----------------
 * This file creates a TablePanel containing a single row.
 */

// ************************************************************************
// *  For the beta release, the source code for the libraries continues   *
// *  to be licensed under the following Creative Commons license:        *
// *                                                                      *
// *                 Attribution-NonCommercial-NoDerivs                   *
// *                                                                      *
// *  When the final release is posted, we plan to reduce these           *
// *  restrictions to allow any use, protecting only the ACM's right      *
// *  to prevent others from selling these libraries as their own.        *
// ************************************************************************

package acm.gui;

/* Class: HPanel */
/**
 * This class represents a horizontal <a href="TablePanel.html"><code>TablePanel</code></a>
 * with a single row.  It is used along with <a href="VPanel.html"><code>VPanel</code></a>
 * to assemble hierarchical collections of panels that can be partitioned into rows
 * and columns.
 */
public class HPanel extends TablePanel {

/* Constructor: HPanel() */
/**
 * Creates a new <code>HPanel</code>.  An <code>HPanel</code> uses a
 * <code>TableLayout</code> manager with a single row.
 *
 * @usage HPanel hbox = new HPanel();
 */
	public HPanel() {
		this(0, 0);
	}

/* Constructor: HPanel(hgap, vgap) */
/**
 * Creates a new <code>HPanel</code> with the specified <code>hgap</code>
 * and <code>vgap</code> parameters, which specify the padding between
 * elements.  For an <code>HPanel</code>, the <code>vgap</code> is used
 * to assign space above and below the row.
 *
 * @usage HPanel hbox = new HPanel(hgap, vgap);
 * @param hgap The gap between columns
 * @param vgap The gap between rows
 */
	public HPanel(int hgap, int vgap) {
		TableLayout layout = new TableLayout(1, 0, hgap, vgap);
		layout.setHorizontalAlignment(TableLayout.FILL);
		layout.setVerticalAlignment(TableLayout.FILL);
		setLayout(layout);
	}
}
