/*
 * File: VPanel.java
 * -----------------
 * This file creates a TablePanel containing a single column.
 */

// ************************************************************************
// *  For the beta release, the source code for the libraries continues   *
// *  to be licensed under the following Creative Commons license:        *
// *                                                                      *
// *                 Attribution-NonCommercial-NoDerivs                   *
// *                                                                      *
// *  When the final release is posted, we plan to reduce these           *
// *  restrictions to allow any use, protecting only the ACM's right      *
// *  to prevent others from selling these libraries as their own.        *
// ************************************************************************

package acm.gui;

/* Class: VPanel */
/**
 * This class represents a vertical <a href="TablePanel.html"><code>TablePanel</code></a>
 * with a single column.  It is used along with <a href="HPanel.html"><code>HPanel</code></a>
 * to assemble hierarchical collections of panels that can be partitioned into rows
 * and columns.
 */
public class VPanel extends TablePanel {

/* Constructor: VPanel() */
/**
 * Creates a new <code>VPanel</code>.  A <code>VPanel</code> uses a
 * <code>TableLayout</code> manager with a single column.
 *
 * @usage VPanel vbox = new VPanel();
 */
	public VPanel() {
		this(0, 0);
	}

/* Constructor: VPanel(hgap, vgap) */
/**
 * Creates a new <code>VPanel</code> with the specified <code>hgap</code>
 * and <code>vgap</code> parameters, which specify the padding between
 * elements.  For a <code>VPanel</code>, the <code>hgap</code> is used
 * to assign space to the left and right of the column.
 *
 * @usage VPanel vbox = new VPanel(hgap, vgap);
 * @param hgap The gap between columns
 * @param vgap The gap between rows
 */
	public VPanel(int hgap, int vgap) {
		TableLayout layout = new TableLayout(0, 1, hgap, vgap);
		layout.setHorizontalAlignment(TableLayout.FILL);
		layout.setVerticalAlignment(TableLayout.FILL);
		setLayout(layout);
	}
}
