/*
 * File: ErrorException.java
 * -------------------------
 * This file defines an exception class for reporting runtime errors
 * in the ACM package suite.
 */

// ************************************************************************
// *  For the beta release, the source code for the libraries continues   *
// *  to be licensed under the following Creative Commons license:        *
// *                                                                      *
// *                 Attribution-NonCommercial-NoDerivs                   *
// *                                                                      *
// *  When the final release is posted, we plan to reduce these           *
// *  restrictions to allow any use, protecting only the ACM's right      *
// *  to prevent others from selling these libraries as their own.        *
// ************************************************************************

package acm.util;

/* Class: ErrorException */
/**
 * This class allows errors to be reported in a consistent way.
 * Clients typically call
 *
 * <p><code>
 * &nbsp;&nbsp;&nbsp;throw new ErrorException(msg);
 * <p></code>
 *
 * <p>Because <code>ErrorException</code> is a subclass of <code>RuntimeException</code>,
 * this exception need not be declared in <code>throws</code> clauses.
 */

public class ErrorException extends RuntimeException {

/* Constructor: ErrorException(msg) */
/**
 * Creates an <code>ErrorException</code> with the specified message.
 *
 * @usage throw new ErrorException(msg);
 * @param msg The error message to be reported
 */
	public ErrorException(String msg) {
		super(msg);
	}

/* Constructor: ErrorException(ex) */
/**
 * Creates an <code>ErrorException</code> using an existing exception.
 *
 * @usage throw new ErrorException(ex);
 * @param ex The exception to be reported
 */
	public ErrorException(Exception ex) {
		super(ex.getClass().getName() + ": " + ex.getMessage());
	}
}
