import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

/**
 * This class shows a random fortune from an array of fortunes.  Use the next
 * button to see the next random fortune.
 * 
 * Ideas for using this class.  
 *  Have students enter their own fortunes in the array.
 *  Have students figure out and code the getRandomFortune() method
 *  Have students read the fortunes from a file.
 *  Have students do the event handling.
 * 
 * @author Barb Ericson
 * Copyright 2004 Georgia Tech
 */
public class FortuneTellerPanel extends JPanel implements ActionListener
{
  /////////////// Fields ////////////////////////////
  private String[] fortunes = {"You will win the lottery!",
                               "You will meet a dark stranger.",
                               "You will hurt your ankle.",
                               "You will get an A in this class.",
                               "You will take a trip soon.",
                               "You will have car trouble.",
                               "You will not get enough sleep.",
                               "You will create a cool video game.",
                               "You will run a marathon.",
                               "You will go to the Olympics!"
                                };
  private JLabel fortuneLabel = new JLabel("Your fortune is: ");
  private JTextField fortuneTextField = new JTextField(60);
  private JButton nextButton = new JButton("Next");
  
  /////////////////// Constructors ////////////////////////
  
  /**
   * No argument constructor 
   */
  public FortuneTellerPanel () 
  {
    // initialize the panel
    initialize();
  }
  
  ////////////////////// Methods ///////////////////////////////
  
  /**
   * Method to initialize this panel
   */
  public void initialize()
  {
    // set the layout to border layout
    this.setLayout(new BorderLayout());
    
    // set up the fortune panel
    JPanel fortunePanel = new JPanel();
    fortunePanel.setLayout(new FlowLayout());
    fortunePanel.add(fortuneLabel);
    fortunePanel.add(fortuneTextField);
    fortuneTextField.setText(getRandomFortune());
    
    // set up the button panel
    JPanel buttonPanel = new JPanel();
    nextButton.addActionListener(this);
    buttonPanel.add(nextButton);
    
    // add to this panel
    this.add(fortunePanel,BorderLayout.NORTH);
    this.add(buttonPanel,BorderLayout.SOUTH);
  }
  
  /**
   * Method to get a random fortune from the array of fortunes
   * @return a string that is the fortune pulled at random from the array
   */
  public String getRandomFortune()
  {
    int index = (int) (Math.random() * fortunes.length);
    return fortunes[index];
  }
  
  /**
   * Method to handle an action event (the next button being pushed)
   */
  public void actionPerformed(ActionEvent evt)
  {
    // show the fortune at this index in the text field
    fortuneTextField.setText(getRandomFortune());
  }
  
  /**
   * Main method for running as an application
   */
  public static void main(String[] argv) 
  {
    FortuneTellerPanel fortuneTeller = new FortuneTellerPanel();
    JFrame frame = new JFrame("Fortune Teller");
    frame.getContentPane().add(fortuneTeller);
    frame.pack();
    frame.setVisible(true);
  }
}
    
    