import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import java.io.*;

/**
 * This class shows a random fortune from an array of fortunes.  Use the next
 * button to see the next random fortune.
 * 
 * Ideas for using this class.  
 *  Have students enter their own fortunes in the array.
 *  Have students figure out and code the getRandomFortune() method
 *  Have students read the fortunes from a file.
 *  Have students do the event handling.
 * 
 * @author Barb Ericson
 * Copyright 2004 Georgia Tech
 */
public class FortuneTellerPanel extends JPanel implements ActionListener
{
  /////////////// Fields ////////////////////////////
  private String[] fortunes = null;
  private String[] defaultFortunes = {"You will win the lottery!",
                               "You will meet a dark stranger.",
                               "You will hurt your ankle.",
                               "You will get an A in this class.",
                               "You will take a trip soon.",
                               "You will have car trouble.",
                               "You will not get enough sleep.",
                               "You will create a cool video game.",
                               "You will run a marathon.",
                               "You will go to the Olympics!"
                                };
  private JLabel fortuneLabel = new JLabel("Your fortune is: ");
  private JTextField fortuneTextField = new JTextField(60);
  private JButton nextButton = new JButton("Next");
  
  /////////////////// Constructors ////////////////////////
  
  /**
   * No argument constructor 
   */
  public FortuneTellerPanel() 
  {
    // use the default fortunes array
    fortunes = defaultFortunes;
    
    // initialize the panel
    initialize();
  }
  
  /**
   * A constructor that takes a file name and reads the fortunes a line
   * at a time from the file.  Or if there is some error it will use the default
   * array of fortunes.
   * @param fileName the name of the file to read from 
   */
  public FortuneTellerPanel(String fileName)
  {
    // read the fortunes from the file
    readFortunesFromFile(fileName);
    
    // initialize the panel
    initialize();
  }
  
  ////////////////////// Methods ///////////////////////////////
  
  /**
   * Method to initialize this panel
   */
  public void initialize()
  {
    // set the layout to border layout
    this.setLayout(new BorderLayout());
    
    // set up the fortune panel
    JPanel fortunePanel = new JPanel();
    fortunePanel.setLayout(new FlowLayout());
    fortunePanel.add(fortuneLabel);
    fortunePanel.add(fortuneTextField);
    fortuneTextField.setText(getRandomFortune());
    
    // set up the button panel
    JPanel buttonPanel = new JPanel();
    nextButton.addActionListener(this);
    buttonPanel.add(nextButton);
    
    // add to this panel
    this.add(fortunePanel,BorderLayout.NORTH);
    this.add(buttonPanel,BorderLayout.SOUTH);
  }
  
  /**
   * Method to get a random fortune from the array of fortunes
   * @return a string that is the fortune pulled at random from the array
   */
  public String getRandomFortune()
  {
    int index = (int) (Math.random() * fortunes.length);
    return fortunes[index];
  }
  
  /**
   * Method to handle an action event (the next button being pushed)
   */
  public void actionPerformed(ActionEvent evt)
  {
    // show the fortune at this index in the text field
    fortuneTextField.setText(getRandomFortune());
  }
  
  /**
   * Method to read the fortunes from the specified file
   * @param fileName the name of the file to read from
   */
  private void readFortunesFromFile(String fileName)
  {
    fortunes = new String[10];
    int index = 0;
    BufferedReader reader = null;
    String line = null;
    
    // try to read the file
    try {
      
      // create the buffered reader
      reader = new BufferedReader(new FileReader(fileName));
      
      // loop reading lines till the line is null (end of file)
      while ((line = reader.readLine()) != null)
      {
        fortunes[index] = line; // add to the array at the current index
        index++; // increment the index
      }
      
      // close the buffered reader
      reader.close();
      
    } catch (Exception ex) {
      fortunes = defaultFortunes;
    }
  }
  
  /**
   * Main method for running as an application
   */
  public static void main(String[] argv) 
  {
    FortuneTellerPanel fortuneTeller = new FortuneTellerPanel("C:\\EricsonConsulting\\HighSchoolWorkshops\\ProgAndSysWorkshop\\ExerciseAnswers\\ReadFromFile\\fortunes.txt");
    JFrame frame = new JFrame("Fortune Teller");
    frame.getContentPane().add(fortuneTeller);
    frame.pack();
    frame.setVisible(true);
  }
}
    
    