/** StepImagePanel - a panel lets the user step through the images using next
 * and previous buttons
 *
 * @author Barb Ericson
 * java version 1.2+
 * */

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import java.net.*;
import java.io.*;

public class StepImagePanel extends JPanel
{

	/******************* private attributes *******************/
	private int currImageIndex = 0;			// the current image index
	private int numImages = 10;			// default number of images
	private String fileName = null;			// base file name for images
	private ImageIcon[] iconArray;			// array of image icons
	private JLabel imageLabel;			// image label
	private String prevFileName = "left.gif";	// file name for previous icon
	private String nextFileName = "right.gif";	// file name for next icon
	private JButton nextButton;			// next button
	private JButton prevButton;			// previous button

	/********************** Constructors ***********************/
	public StepImagePanel(String fileName,int numImages)
	{
		// set local variables
		this.fileName = fileName;
		this.numImages = numImages;

		// initialize the panel
		init();

	}

	/********************** public methods ********************/

	/********************** private methods *******************/

	/** Method to create and initialize the previous button */
	private void createAndInitPrevButton()
	{

		// add a previous button
		prevButton = new JButton("Previous");
		prevButton.addActionListener(new ActionListener () {
		  public void actionPerformed(ActionEvent e)
		  {
		    // show previous
		    currImageIndex = currImageIndex - 1;
		    if (currImageIndex < 0)
		      currImageIndex = numImages - 1;
		    imageLabel.setIcon(iconArray[currImageIndex]);
		    repaint();
		  }
		});
	}

	/** Method to create and initialize the next button */
	private void createAndInitNextButton()
	{

		// add a next button
		nextButton = new JButton("Next");
		nextButton.addActionListener(new ActionListener () {
		  public void actionPerformed(ActionEvent e)
		  {
		    // show next
		    currImageIndex = currImageIndex + 1;
		    if (currImageIndex >= numImages)
		      currImageIndex = 0;
		    imageLabel.setIcon(iconArray[currImageIndex]);
		    repaint();
	          }
		});
	}

	/** Method to create and initialize the image icon array */
	private void createAndInitImageIconArray()
	{

		String fullFileName;	// full file name

		// create the image icon array
		iconArray = new ImageIcon[numImages];

		// loop creating the image icons
		for (int i=0; i<numImages; i++)
		{
			// create the full file name for the image file
			fullFileName = fileName + i + ".gif";

			// create the image icon and add it to the array
			iconArray[i] = new ImageIcon(fullFileName);
		}

	}

	/** Method to set up the panel */
	private void init()
	{

		// set the panel layout to border layout
		setLayout(new BorderLayout());

		// create and initialize the image icon array
		createAndInitImageIconArray();

		// create the image label with the first image and add to the center of the panel
		imageLabel = new JLabel(iconArray[0]);
		add(imageLabel,BorderLayout.CENTER);

		// create a button panel
		JPanel buttonPanel = new JPanel();

		// create and initialize the previous button
		createAndInitPrevButton();
		buttonPanel.add(prevButton);

		// create and initialize the next button
		createAndInitNextButton();
		buttonPanel.add(nextButton);

		// add button panel to the south
		add(buttonPanel,BorderLayout.SOUTH);
	}

}