/** Person class - holds information about a person such as a person id, title, 
      first name, middle name, last name, phone number, and e-mail address

     @author Barb Ericson
     Java Version 1.0+
 */

public class Person 
{

	/* ************************ Private attributes **************************/
	private int id;			// a unique number per person
	private String title;		// the title for this person
	private String firstName;	// first name of this person
	private String middleName;	// middle name of this person
	private String lastName;	// last name of this person
	private String phoneNumber; 	// a phone number to use to reach this person
	private String eMailAddress; 	// an e-mail address to use to reach this person

	private static int nextId = 1;	// class attribute for the next id to use 

	/* ************************ Constructors ****************************/

	/** Constructor that takes all arguments except the id which will be 
            automatically assigned, phone number, and e-mail */
	public Person(String title, String firstName, String middleName, 
                      String lastName)
                      
	{
		// set the id to the next available id and increment the next id
		this.id = nextId++;

		// set the object attribute values to the passed values
		this.title = title;
		this.firstName = firstName;
		this.middleName = middleName;
		this.lastName = lastName;
	}

	/** Constructor that takes all arguments except the id which will be 
            automatically assigned */
	public Person(String title, String firstName, String middleName, 
                      String lastName, String phoneNumber, String eMailAddress)
                      
	{
		// set the id to the next available id and increment the next id
		this.id = nextId++;

		// set the object attribute values to the passed values
		this.title = title;
		this.firstName = firstName;
		this.middleName = middleName;
		this.lastName = lastName;
		this.phoneNumber = phoneNumber;
		this.eMailAddress = eMailAddress;
	}

	/** Constructor that takes all arguments */
	public Person(int id, String title, String firstName, String middleName, 
                      String lastName, String phoneNumber, String eMailAddress)
                      
	{
		// set the object attribute values to the passed values
		this.id = id;
		this.title = title;
		this.firstName = firstName;
		this.middleName = middleName;
		this.lastName = lastName;
		this.phoneNumber = phoneNumber;
		this.eMailAddress = eMailAddress;
	}

	/* ********************** Public methods *******************************/

	/* ********************** Getters and setters  *******************************/

	/** Method to get the id 
         @return an <code> integer </code> that is the unique identifier for 
         this person */
	public int getId() { return id; }

	/** Method to get the title 
         @return a <code> String </code> which is the title to use 
         such as: Mr., Ms., Dr. ... */
	public String getTitle() { return title; }

	/** Method to get the first name 
         @return a <code> String </code> which is the first name of the person */
	public String getFirstName() { return firstName; }

        /** Method to get the middle name 
         @return a <code> String </code> which is the middle name of the person */
	public String getMiddleName() { return middleName; }

	/** Method to get the last  name 
         @return a <code> String </code> which is the last  name of the person */
	public String getLastName() { return lastName; }

	/** Method to get a phone number to use to reach this person
	 @return a <code> String </code> which is a phone number to use to reach the 
         person */
	public String getPhoneNumber() { return phoneNumber; }

	/** Method to get an e-mail address for this person 
	 @return a <code> String </code> which is an e-mail address to
          use to reach this person */
      	public String getEMailAddress() { return eMailAddress; }

	/** Method to set the id 
	 @param id the identifier for the person */
	public void setId(int id) { this.id = id; }

	/** Method to set the title
	 @param title the title for the person */
	public void setTitle(String title) { this.title = title;}

	/** Method to set the first name
	 @param firstName the first name for the person */
	public void setFirstName(String firstName) 
	{ this.firstName = firstName; }

        /** Method to set the middle name 
	 @param middleName the middle name for the person */
        public void setMiddleName(String middleName) 
	{ this.middleName = middleName; }

        /** Method to set the last name 
	 @param lastName the last name for the person */
        public void setLastName(String lastName) 
	{this.lastName = lastName; }

       /** Method to print the person information to the console */
       public void print()
       {
		// print out the id
		System.out.println("Id: " + id);

		// print out the full name with the title 
		System.out.println("Name: " + title + " " + firstName + " " +
                                   middleName + " " + lastName);

		// print out the phone number
		if (phoneNumber != null)
		   System.out.println("Phone Number: " + phoneNumber);
		
		// print out the e-mail address
		if (eMailAddress != null)
		   System.out.println("E-mail Address: " + eMailAddress);
       }

       /* ******************Main method for testing as an application *************************/
       public static void main (String argv[])
       {
		// create a new person and print out the information
		Person currPerson = new Person("Ms.","Betty","L.","Rubble");
		currPerson.print();

		// create a new person and print out the information
		Person nextPerson = new Person("Mr.", "Fred", "R.", "Flintstone");
		nextPerson.print();

		// create a new person with my information 
		Person me = new Person("Ms.", "Barbara", "Jane", "Ericson",
                           "(404) XXX-XXXX","ericson@mindspring.com");
		me.print();
       }
}
