/*
 * File: Broccoli.java
 * -------------------
 * This file defines the class that assembles a broccoli plant
 * recursively.
 */

import acm.graphics.*;

import java.awt.*;

/**
 * Class to recursively draw broccoli
 */
public class Broccoli implements BroccoliPart {
  // dark green color for broccoli
  private static final Color BROCCOLI_COLOR = new Color(0,135,0);

  // Below this size draw flower
  private static final double MINSIZE = 25.0;

  // How much broccoli shrinks each call
  private final static double TOP_FRACT = 0.8;

  // stem of broccoli
  private GLine stem;

  // branches of broccoli
  private BroccoliPart left, center, right;

  /**
   * Draw broccoli by recursively drawing branches (and flower)
   */
  public Broccoli(double startX, double startY, double size,
                        double direction, GCanvas canvas)
  {
  	double endX = startX + size*GMath.cosDegrees(direction);
  	double endY = startY - size*GMath.sinDegrees(direction);
  	
    // Draw stem and color green
    stem = new GLine(startX, startY, endX, endY);
    canvas.add(stem);
    stem.setColor(BROCCOLI_COLOR);

  
    if ( size > MINSIZE ) {                  // draw branches
      left = new Broccoli(endX, endY, size * TOP_FRACT,
                                direction + 20, canvas);
      center = new Broccoli(endX, endY, size * TOP_FRACT,
                                  direction, canvas);
      right = new Broccoli(endX, endY, size * TOP_FRACT,
                                 direction - 20, canvas);
    } else {                                 // draw flowers
      left = new BroccoliFlower(endX, endY, size * TOP_FRACT,
                        direction + 20, canvas);
      center = new BroccoliFlower(endX, endY, size * TOP_FRACT,
                          direction, canvas);
      right = new BroccoliFlower(endX, endY, size * TOP_FRACT,
                         direction - 20, canvas);
    }

  }

  /**
   * @param x,y amount to move broccoli
   */
  public void move( double x, double y ) {
    stem.move(x,y);					// move stem

    left.move(x,y);					// move other parts
    center.move(x,y);
    right.move(x,y);
  }

  /**
   * @param point location to be checked for containment in broccoli
   */
  public boolean contains( GPoint pt ) {
    return (stem.contains(pt) || left.contains(pt) ||
            center.contains(pt) || right.contains(pt));
  }

}