/*
 * File: BroccoliFlower.java
 * -------------------------
 * This file defines the class that draws a broccoli flower.
 */

import acm.graphics.*;

import java.awt.*;

/**
 * Class to draw a broccoli flower
 */
public class BroccoliFlower implements BroccoliPart {

  private static final Color BROCCOLI_COLOR = new Color(0,135,0);
  private static final int BUD_SIZE = 3;  // diameter of bud

  private GLine stem;				    // stem of broccoli

  private GOval bud;		// flower of broccoli plant

  /**
   * Draw flower
   */
  public BroccoliFlower(double startX, double startY, double size,
                double direction, GCanvas canvas) {
  	double endX = startX + size*GMath.cosDegrees(direction); // end of stem
  	double endY = startY - size*GMath.sinDegrees(direction);

  	// Draw stem and color green
    stem = new GLine(startX, startY, endX, endY);
    canvas.add(stem);
    stem.setColor(BROCCOLI_COLOR);

    bud = new GOval(BUD_SIZE,BUD_SIZE);
    bud.setFilled(true);
    canvas.add(bud, endX, endY);
    bud.setColor(Color.yellow);
  }

  /**
   * @param x,y amount to move flower
   */
  public void move(double x, double y) {
    // move stem
    stem.move(x,y);

    // move bud
    bud.move(x,y);
  }

  /**
   * @param point location to be checked for containment in flower
   */
  public boolean contains (GPoint pt) {
    return stem.contains(pt) || bud.contains(pt);
  }


}