/*
 * File: CurrencyConverter.java
 * ----------------------------
 * This program illustrates the GUI layout mechanism to create
 * a simple currency converter.
 */

import acm.gui.*;
import acm.program.*;

import java.awt.event.*;

import javax.swing.*;

/** This class implements a simple currency converter. */
public class CurrencyConverter extends Program {

/** Set the program dimensions */
	public static final int APPLICATION_WIDTH = 350;
	public static final int APPLICATION_HEIGHT = 200;

/** Initialize the GUI */
	public void init() {
		setLayout(new TableLayout(4, 2));
		String date = "(rates from " + tableDate + ")";
		leftChooser = new JComboBox(createCurrencyArray());
		leftChooser.setSelectedItem("US Dollar");
		rightChooser = new JComboBox(createCurrencyArray());
		rightChooser.setSelectedItem("Euro");
		leftField = new DoubleField();
		leftField.setFormat("0.00");
		leftField.setActionCommand("Convert ->");
		leftField.addActionListener(this);
		rightField = new DoubleField();
		rightField.setFormat("0.00");
		rightField.setActionCommand("<- Convert");
		rightField.addActionListener(this);
		add(leftChooser);
		add(rightChooser);
		add(leftField);
		add(rightField);
		add(new JButton("Convert ->"));
		add(new JButton("<- Convert"));
		add(new JLabel(date, JLabel.CENTER), "gridwidth=2");
		addActionListeners();
	}

/** Listens for a button action. */
	public void actionPerformed(ActionEvent e) {
		String cmd = e.getActionCommand();
		if (cmd.equals("Convert ->")) {
			double fromValue = leftField.getValue();
			double fromRate = currencyTable[leftChooser.getSelectedIndex()].getExchangeRate();
			double toRate = currencyTable[rightChooser.getSelectedIndex()].getExchangeRate();
			double toValue = fromValue * fromRate / toRate;
			rightField.setValue(toValue);
		} else if (cmd.equals("<- Convert")) {
			double fromValue = rightField.getValue();
			double fromRate = currencyTable[rightChooser.getSelectedIndex()].getExchangeRate();
			double toRate = currencyTable[leftChooser.getSelectedIndex()].getExchangeRate();
			double toValue = fromValue * fromRate / toRate;
			leftField.setValue(toValue);
		}
	}

/** Create an array of strings from the currency table. */
	private String[] createCurrencyArray() {
		int nCurrencies = currencyTable.length;
		String[] names = new String[nCurrencies];
		for (int i = 0; i < nCurrencies; i++) {
			names[i] = currencyTable[i].getCurrencyName();
		}
		return names;
	}

/* Currency table (Source: Interbank Rate for 22-Jul-05) */
	private String tableDate = "22-Jul-05";
	private CurrencyEntry[] currencyTable = {
		new CurrencyEntry("Australian Dollar", 0.766),
		new CurrencyEntry("Brazilian Real", 0.435),
		new CurrencyEntry("British Pound", 1.754),
		new CurrencyEntry("Canadian Dollar", 0.821),
		new CurrencyEntry("Chinese Yuan", 0.121),
		new CurrencyEntry("Euro", 1.218),
		new CurrencyEntry("Japanese Yen", 0.00908),
		new CurrencyEntry("Mexican Peso", 0.942),
		new CurrencyEntry("South African Rand", 0.153),
		new CurrencyEntry("Swiss Franc", 0.779),
		new CurrencyEntry("US Dollar", 1.000)
	};

/* Private instance variables */

	private JComboBox leftChooser;
	private JComboBox rightChooser;
	private DoubleField leftField;
	private DoubleField rightField;
}

/* Package class: CurrencyEntry */
/**
 * This class is used to store the name of a currency together with
 * its relative value in comparison to the other currencies.  The
 * example defines the dollar as 1.0, but the code does not depend
 * on that definition.
 */

class CurrencyEntry {

	public CurrencyEntry(String name, double rate) {
		currencyName = name;
		exchangeRate = rate;
	}

	public String getCurrencyName() {
		return currencyName;
	}

	public double getExchangeRate() {
		return exchangeRate;
	}

	private String currencyName;
	private double exchangeRate;

}
