import acm.graphics.*;
import java.awt.*;

/**
 * A graphical type that looks a bit like a T-shirt with a body, 
 * sleeves and a neck.
 */ 
public class TShirt extends GCompound {
    // The fundamental size of the shirt, all the other dimensions
    // are defined in terms of this
    private static final double SIZE = 120;

    // Sizes of the various components of the shirt
    private static final double SLEEVE_WIDTH = SIZE;
    private static final double SLEEVE_HEIGHT = 0.2 * SIZE;

    private static final double BODY_WIDTH = 0.6 * SIZE;
    private static final double BODY_HEIGHT = 0.65 * SIZE;

    private static final double NECK_WIDTH = 0.3 * SIZE;
    private static final double NECK_HEIGHT = 0.06 * SIZE;

    // Offsets of the body and neck components from the left of the shirt
    private static final double BODY_OFFSET = 0.2 * SIZE;
    private static final double NECK_OFFSET = 0.35 * SIZE;

    private GRect sleeves;       // The sleeves of the shirt  
    private GOval neck;          // The neck of the shirt

    private GRect bodyOutline;   // The outline of the body of the shirt
    private GRect bodyInterior;  // The interior of the body of the shirt

    /**
     * Create a shirt. The initial color is white with a (default) black outline
     */
    public TShirt() {
        /* Create the components of the shirt and add them to the GCompound 
         * object. Order is important here: the first component added will be
         * at the "back" of the compound object, the last at the front.
         */
        
        // First the outline of the body.
        // Its color will be the color of the shirt's outline.
        bodyOutline = new GRect(BODY_WIDTH, BODY_HEIGHT);
        add(bodyOutline, BODY_OFFSET, NECK_HEIGHT / 2);
        
        // Then the sleeves (outline and interior)
        // This will obscure the unwanted portions of the body's outline.
        sleeves = new GRect(SLEEVE_WIDTH, SLEEVE_HEIGHT);
        sleeves.setFilled(true);
        sleeves.setFillColor(Color.WHITE);
        add(sleeves, 0, NECK_HEIGHT / 2);
        
        // Then the interior of the body.
        // This will obscure the unwanted portions of the sleeves' outline.
        bodyInterior = new GRect(BODY_WIDTH - 2, BODY_HEIGHT - 2);
        bodyInterior.setColor(Color.WHITE);
        bodyInterior.setFilled(true);
        bodyInterior.setFillColor(Color.WHITE);
        add(bodyInterior, BODY_OFFSET + 1, NECK_HEIGHT / 2 + 1);
        
        // Finally the neck.
        neck = new GOval(NECK_WIDTH, NECK_HEIGHT);
        add(neck, NECK_OFFSET, 0);
        neck.setFilled(true);
        neck.setFillColor(Color.WHITE);
    }

    /**
     * Change the color of the shirt to new
     * We can not use the default behaviour for this, because it 
     * would conflict with the way we are doing the body's outline.
     */
    public void setFillColor(Color newColor) {
        neck.setFillColor(newColor);
        sleeves.setFillColor(newColor);
        bodyInterior.setFillColor(newColor);
        bodyInterior.setColor(newColor);
        // Don't change the color of the body outline
    }
    
    /**
     * Change the color of the outline of the shirt to newColor.
     * We cannot use the default behaviour for this, because it 
     * would conflict with the way we are doing the body's outline.
     */
    public void setColor(Color newColor) {
        bodyOutline.setColor(newColor);
        bodyOutline.setFillColor(newColor);
        neck.setColor(newColor);
        sleeves.setColor(newColor);
        // Don't change the color of the body's interior
    }
}
