/*
 * File: TShirtDemo.java
 * ---------------------
 * This program demonstrates object-dragging by listening to
 * events in the canvas.  This program also illustrates the
 * style in which the run method acquires the canvas explicitly
 * and then adds objects to that canvas, rather than relying on
 * the GraphicsProgram forwarding the add message to the canvas.
 * This style emphasizes that the add message has a receiver.
 */

import acm.graphics.*;
import acm.program.*;
import java.awt.*;
import java.awt.event.*;

/**
 * Drag a shirt around window, given a choice
 * of a red shirt or a blue shirt
 */
public class TShirtDemo extends GraphicsProgram {

// Starting location of the first shirt
    private static final int ITEM_LEFT = 75;
    private static final int ITEM_TOP = 50;
    
// Offset of the second shirt from the first
    private static final int BLUE_SHIRT_OFFSET = 150;

// The shirts themselves
    private TShirt redShirt, blueShirt, selectedShirt;

// The previously noted position of mouse cursor
    private GPoint lastPoint;

// The graphical canvas
    private GCanvas canvas;

/**
 * Initialize the application by creating the shirts and
 * setting up the drag handler
 */
    public void init() {
        canvas = getGCanvas();
        
        redShirt = new TShirt();
        redShirt.setFillColor(Color.RED);
        canvas.add(redShirt, ITEM_LEFT, ITEM_TOP);
        
        blueShirt = new TShirt();
        blueShirt.setFillColor(Color.BLUE);
        blueShirt.setColor(Color.GREEN);
        canvas.add(blueShirt, ITEM_LEFT + BLUE_SHIRT_OFFSET, ITEM_TOP);

		addMouseListeners();
    }

/** 
 * Whenever the mouse is depressed, note its location
 * and which (if any) shirt the mouse is on
 */
    public void mousePressed(MouseEvent e) {
    	lastPoint = new GPoint(e.getX(), e.getY());
    	if (redShirt.contains(lastPoint)) {
        	selectedShirt = redShirt;
        } else if (blueShirt.contains(lastPoint)) {
        	selectedShirt = blueShirt;
        } else {
        	selectedShirt = null;
        } 
    }

/**
 * If the mouse is being dragged, move the selected shirt with it
 */
    public void mouseDragged(MouseEvent e) {
        double x = e.getX();
        double y = e.getY();
        if (selectedShirt != null) {
            selectedShirt.move(x - lastPoint.getX(),
                               y - lastPoint.getY());
            lastPoint = new GPoint(x, y);
        }
    }
}
