/*
 * File: TemperatureConverter.java
 * -------------------------------
 * This program illustrates the GUI layout mechanism to create
 * a more general temperature converter.  In contrast to the
 * FahrenheitToCelsius example included with BreezySwing,
 * the TemperatureConverter application allows the user to
 * convert in both directions and enables action events
 * for the input fields.
 */

import acm.gui.*;
import acm.program.*;

import java.awt.event.*;

import javax.swing.*;

/** This class implements a simple temperature converter. */
public class TemperatureConverter extends Program {

/** Set the program dimensions */
	public static final int APPLICATION_WIDTH = 300;
	public static final int APPLICATION_HEIGHT = 200;

/** Initialize the application */
	public void init() {
		setLayout(new TableLayout(2, 3));
		fahrenheitField = new IntField(32);
		fahrenheitField.setActionCommand("F -> C");
		fahrenheitField.addActionListener(this);
		celsiusField = new IntField(0);
		celsiusField.setActionCommand("C -> F");
		celsiusField.addActionListener(this);
		add(new JLabel("Degrees Fahrenheit"));
		add(fahrenheitField);
		add(new JButton("F -> C"));
		add(new JLabel("Degrees Celsius"));
		add(celsiusField);
		add(new JButton("C -> F"));
		addActionListeners();
	}

/** Listen for a button action. */
	public void actionPerformed(ActionEvent e) {
		String cmd = e.getActionCommand();
		if (cmd.equals("F -> C")) {
			int f = fahrenheitField.getValue();
			int c = (int) Math.round( (5.0 / 9.0) * (f - 32) );
			celsiusField.setValue(c);
		} else if (cmd.equals("C -> F")) {
			int c = celsiusField.getValue();
			int f = (int) Math.round( (9.0 / 5.0) * c + 32 );
			fahrenheitField.setValue(f);
		}
	}

/* Private instance variables */

	private IntField fahrenheitField;
	private IntField celsiusField;
}
