import java.awt.*;
import java.io.*;

/**
 * Class to create frames for a movie
 * @author Barb Ericson
 */
public class MovieMaker
{
  
  /**
   * Method to make a movie that has a rectangle moving 
   * around
   * @param directory the directory to put the movie
   * frames
   */
  public void makeRectangleMovie(String directory)
  {
    int framesPerSec = 30;
    Picture p = null;
    Graphics g = null;
    FrameSequencer frameSequencer = 
      new FrameSequencer(directory);
    frameSequencer.setShown(true);
    
    // loop through the first second
    for (int i = 0; i < framesPerSec; i++)
    {
      // draw a filled rectangle
      p = new Picture(640,480);
      g = p.getGraphics();
      g.setColor(Color.RED);
      g.fillRect(i * 10, i * 5, 50,50);
      
      // add frame to sequencer
      frameSequencer.addFrame(p);
    }
    
    // play the movie
    frameSequencer.play(framesPerSec);
  }
  
  /**
   * Method to create a tickertape movie
   * @param directory the directory to write to
   * @param message the string to display
   */
  public void makeTickerTapeMovie(String directory, 
                                  String message)
  {
    int framesPerSec = 30;
    Picture p = null;
    Graphics g = null;
    FrameSequencer frameSequencer = 
      new FrameSequencer(directory);
    Font font = new Font("Arial",Font.BOLD,24);
    
    // loop for 2 seconds of animation
    for (int i = 0; i < framesPerSec * 2; i++)
    {
      // draw the string
      p = new Picture(300,100);
      g = p.getGraphics();
      g.setColor(Color.BLACK);
      g.setFont(font);
      g.drawString(message,300 - (i * 10), 50);
      
      // add frame to sequencer
      frameSequencer.addFrame(p);
    }
    
    // play the movie
    frameSequencer.play(framesPerSec);
  }
  
  /**
   * Method to make a movie that has a two rectangles moving 
   * around
   * @param directory the directory to put the movie
   * frames
   */
  public void makeTwoRectangleMovie(String directory)
  {
    int framesPerSec = 30;
    Picture p = null;
    Graphics g = null;
    FrameSequencer frameSequencer = 
      new FrameSequencer(directory);
    
    // loop through the first second
    for (int i = 0; i < framesPerSec; i++)
    {
      // draw a filled rectangle
      p = new Picture(640,480);
      g = p.getGraphics();
      g.setColor(Color.RED);
      g.fillRect(i * 10, i * 5, 50,50);
      g.setColor(Color.BLUE);
      g.fillRect(100 + (int) (10 * Math.sin(i)),
                 4 * i + (int) (10 * Math.cos(i)),
                 50,50);
      
      // add frame to sequencer
      frameSequencer.addFrame(p);
    }
    
    // play the movie
    frameSequencer.play(framesPerSec);
  }
  
  /**
   * Method to move Mark's head around
   */
  public void moveMarksHead(String directory)
  {
    // load the picture of Mark
    String fName = FileChooser.getMediaPath("blue-Mark.jpg");
    Picture markP = new Picture(fName);
    
    // declare other variables
    Picture target = null;
    FrameSequencer frameSequencer = 
      new FrameSequencer(directory);
    int framesPerSec = 30;
    
    // loop creating the frames
    for (int i = 0; i < framesPerSec; i++)
    {
      target = new Picture(640,480);
      target.copy(markP,281,164,382,301,i * 10, i * 5);
      frameSequencer.addFrame(target);
    } 
    
    // play the movie
    frameSequencer.play(framesPerSec);
  }
  
  /**
   * Method to slowly create a sunset
   * @param directory the directory to write to
   */
  public void makeSunsetMovie(String directory)
  {
    // load the picture of the beach
    String fName = FileChooser.getMediaPath("beach-smaller.jpg");
    Picture beachP = new Picture(fName);
    
    // declare other variables
    Picture target = null;
    FrameSequencer frameSequencer = 
      new FrameSequencer(directory);
    int framesPerSec = 30;
    
    // loop creating the frames
    for (int i = 0; i < framesPerSec; i++)
    {
      beachP.makeSunset(0.95);
      frameSequencer.addFrame(beachP);
    } 
    
    // play the movie
    frameSequencer.play(framesPerSec);
  }
  
   /**
   * Method to create a movie that fades out the person from
   * one background to another.
   * @param directory the directory to write to
   */
  public void makeFadeOutMovie(String directory)
  {
    // load the pictures
    String kidF = FileChooser.getMediaPath("kid-in-frame.jpg");
    Picture kidP = null;
    String wallF = FileChooser.getMediaPath("bgframe.jpg");
    Picture wallP = new Picture(wallF);
    String beachF = FileChooser.getMediaPath("beach.jpg");
    Picture beachP = new Picture(beachF);

    // declare other variables
    FrameSequencer frameSequencer = 
      new FrameSequencer(directory);
    int framesPerSec = 30;

    // loop creating the frames
    for (int i = 0; i < framesPerSec * 2; i++)
    {
      kidP = new Picture(kidF);
      kidP.swapBackground(wallP,beachP,i);
      frameSequencer.addFrame(kidP);
    }

    // play the movie
    frameSequencer.play(framesPerSec);
  }
  
  /**
   * Method to make a movie of barb's head moving
   * and katie dancing
   * @param dir the directory to read from and write to
   */
  public void makeMommyWatchingMovie(String dir)
  {
    String barbF = FileChooser.getMediaPath("barbaraS.jpg");
    String katieDir = 
      FileChooser.getMediaPath("kid-in-bg-seq/");
    Picture barbP = new Picture(barbF);
    FrameSequencer frameSequencer = new FrameSequencer(dir);
    Picture currP = null;
    
    // get the array of files in the directory
    File dirObj = new File(katieDir);
    String[] fileArray = dirObj.list();
    
    // loop through the array of files
    for (int i = 0; i < fileArray.length; i++)
    {
      if (fileArray[i].indexOf(".jpg") >= 0)
      {
        currP = new Picture(katieDir + fileArray[i]);
        currP.copy(barbP,22,9,93,97,i * 3, i * 3);
        frameSequencer.addFrame(currP);
      }
    }
    
    // play the movie
    frameSequencer.play(30);
  }
  
  /**
   * Method to make a movie of the kids crawling on the moon
   * @param dir the directory to write the frames to
   */
  public void makeKidsOnMoonMovie(String dir)
  {
    String kidsDir = FileChooser.getMediaPath("kids-blue/");
    String moonF = FileChooser.getMediaPath("moon-surface.jpg");
    Picture moonP = new Picture(moonF);
    FrameSequencer frameSequencer = new FrameSequencer(dir);
    Picture currP = null;
    
    // get the array of files in the directory
    File dirObj = new File(kidsDir);
    String[] fileArray = dirObj.list();
    
    // loop through the array of files
    for (int i = 0; i < fileArray.length; i++)
    {
      if (fileArray[i].indexOf(".jpg") >= 0)
      {
        currP = new Picture(kidsDir + fileArray[i]);
        currP.chromakey(moonP,Color.black,100.0);
        frameSequencer.addFrame(currP);
      }
    }
    
    // play the movie
    frameSequencer.play(30);
  }
  
  /**
   * Method to lighten the pixels that are near black in 
   * a movie
   * @param dir the directory to write the frames to
   */
  public void makeLighterMovie(String dir)
  {
    String movieDir = FileChooser.getMediaPath("dark-fish2/");
    FrameSequencer frameSequencer = new FrameSequencer(dir);
    Picture currP = null;
    
    // get the array of files in the directory
    File dirObj = new File(movieDir);
    String[] fileArray = dirObj.list();
    
    // loop through the array of files
    for (int i = 0; i < fileArray.length; i++)
    {
      if (fileArray[i].indexOf(".jpg") >= 0)
      {
        currP = new Picture(movieDir + fileArray[i]);
        currP.lighten(Color.BLACK,8,5);
        frameSequencer.addFrame(currP);
      }
    }
    
    // play the movie
    frameSequencer.play(30);
  }
  
  /**
   * Method to change the red and green values in the frames
   * @param dir the directory to write the frames to
   */
  public void makeFishMovie(String dir)
  {
    String movieDir = FileChooser.getMediaPath("fish/");
    FrameSequencer frameSequencer = new FrameSequencer(dir);
    Picture currP = null;
    
    // get the array of files in the directory
    File dirObj = new File(movieDir);
    String[] fileArray = dirObj.list();
    
    // loop through the array of files
    for (int i = 0; i < fileArray.length; i++)
    {
      if (fileArray[i].indexOf(".jpg") >= 0)
      {
        currP = new Picture(movieDir + fileArray[i]);
        currP.changeRedAndGreen(2.0,1.5);
        frameSequencer.addFrame(currP);
      }
    }
    
    // play the movie
    frameSequencer.play(16);
  }
  
  public static void main(String[] args)
  {
    MovieMaker movieMaker = new MovieMaker();
    //String dir = "c:/intro-prog-java/movies/rectangle/";
    //movieMaker.makeRectangleMovie(dir);
    //String dir = "c:/intro-prog-java/movies/tickertape/";
    //movieMaker.makeTickerTapeMovie(dir,"Buy more widgets");
    //String dir = "c:/intro-prog-java/movies/rectangle2/";
    //movieMaker.makeTwoRectangleMovie(dir);
    //String dir = "c:/intro-prog-java/movies/mark/";
    //movieMaker.moveMarksHead(dir);
    //String dir = "c:/intro-prog-java/movies/sunset/";
    // movieMaker.makeSunsetMovie(dir);
    String dir = "c:/intro-prog-java/movies/fade/";
    movieMaker.makeFadeOutMovie(dir);
   // String dir = "c:/intro-prog-java/movies/mommy/";
   // movieMaker.makeMommyWatchingMovie(dir);
    //String dir = "c:/intro-prog-java/movies/moon/";
    //movieMaker.makeKidsOnMoonMovie(dir);
    //String dir = "c:/intro-prog-java/movies/lighter/";
    //movieMaker.makeLighterMovie(dir);
    //String dir = "c:/intro-prog-java/movies/fish/";
    //movieMaker.makeFishMovie(dir);
  }
      
}