import java.util.*;

/**
 * Class that represents a turtle which is similar to a Logo turtle.
 * This class inherts from SimpleTurtle and is for students
 * to add methods to.
 *
 * Copyright Georgia Institute of Technology 2004
 * @author Barb Ericson ericson@cc.gatech.edu
 */
public class Turtle extends SimpleTurtle
{
  ////////////////// constructors ///////////////////////
  
  /** Constructor that takes the x and y and a picture to
   * draw on
   * @param x the starting x position
   * @param y the starting y position
   * @param picture the picture to draw on
   */
  public Turtle (int x, int y, Picture picture) 
  {
    // let the parent constructor handle it
    super(x,y,picture);
  }
  
  /** Constructor that takes the x and y and a model
   * display to draw it on
   * @param x the starting x position
   * @param y the starting y position
   * @param modelDisplayer the thing that displays the model
   */
  public Turtle (int x, int y, ModelDisplay modelDisplayer) 
  {
    // let the parent constructor handle it
    super(x,y,modelDisplayer);
  }
  
  /** Constructor that takes the model display
   * @param modelDisplay the thing that displays the model
   */
  public Turtle (ModelDisplay modelDisplay) 
  {
    // let the parent constructor handle it
    super(modelDisplay);
  }
  
  /**
   * Constructor that takes a picture to draw on
   * @param p the picture to draw on
   */
  public Turtle (Picture p)
  {
    // let the parent constructor handle it
    super(p);
  }
  
  /////////////////// methods ///////////////////////
  
  /** 
   * Method to draw a square with a width and height
   * of 30 
   */
  public void drawSquare()
  {
    this.turnRight();
    this.forward(30);
    this.turnRight();
    this.forward(30);
    this.turnRight();
    this.forward(30);
    this.turnRight();
    this.forward(30);
  }
  
  /**
   * Method to draw a square with a width and height
   * of 30. Second version
   */
  public void drawSquare2()
  {
    int width = 30;
    this.turnRight();
    this.forward(width);
    this.turnRight();
    this.forward(width);
    this.turnRight();
    this.forward(width);
    this.turnRight();
    this.forward(width);
  }
  
  /**
   * Method to draw a square with a width and height
   * of some passed amount.
   * @param width the width and height to use
   */
  public void drawSquare(int width)
  {
    this.turnRight();
    this.forward(width);
    this.turnRight();
    this.forward(width);
    this.turnRight();
    this.forward(width);
    this.turnRight();
    this.forward(width);
  }
  
  /**
   * Recursive method to draw a tree structure
   * @param branchLength the length of the 
   * current branch
   */
  public void drawTree(int branchLength)
  {
    
    // only continue if the branch is greater than 5
    if (branchLength > 5)
    {
      // move this turtle forward by the branch length
      this.forward(branchLength);
      
      // modify the length of the next branches
      branchLength = (int) (0.8 * branchLength);
      
      // get the current turtle values
      int x = this.getXPos();
      int y = this.getYPos();
      ModelDisplay display = this.getModelDisplay();
      
      // create a child to handle the left branch
      Turtle leftChild = new Turtle(x,y,display);
      leftChild.setHeading(this.getHeading());
      leftChild.turn(-30);
      leftChild.drawTree(branchLength);
      
      // create a child to handle the right branch
      Turtle rightChild = new Turtle(x,y,
                                this.getModelDisplay());
      rightChild.setHeading(this.getHeading());
      rightChild.turn(30);
      rightChild.drawTree(branchLength);
    }
    this.hide();
  }
  
  /**
   * Method to make the turtles dance
   */
  public static void dance() throws java.lang.Exception  
  {
    World w = new World();
    w.setAutoRepaint(false);
    Turtle[] turtleArray = new Turtle[11];
    
    // create the turtles
    for (int i = 0; i < turtleArray.length; i++)
    {
      turtleArray[i] = new Turtle(w);
      turtleArray[i].turn(i * 36);
    }
    w.repaint();
    Thread.sleep(1000);
    
    // dance
    for (int i = 5; i < 30; i=i+5) {
      for (int j = 1; j < turtleArray.length; j++) {
      turtleArray[j].forward(i);
      turtleArray[j].turn(10);
      }
      w.repaint();
      Thread.sleep(1000);
    }
  }
  
//  public static void main(String[] args)
//  {
//    World w = new World();
//    w.setAutoRepaint(false);
//    Turtle t = new Turtle(320,480,w);
//    t.drawTree(100);
//    w.repaint();
//  }  
  
} // end of class (do not remove this and put new methods before it)